pub enum Error {
ComponentRange(ComponentRange),
DateTooLarge,
}Available on crate feature
posix-tz only.Expand description
The type of error return when a given Offset/PrimitiveDateTime cannot be represented in a given POSIX TZ formatted “timezone”.
Variants
ComponentRange(ComponentRange)
We’ve exceeded the range of a date component when converting types to time-rs.
DateTooLarge
We’ve exceeded the maximum date supported by time-rs.