pub enum ParseError<'a> {
Nom(ErrorKind),
UnknownName(&'a str),
Range(RangeError),
ComponentRange(ComponentRange),
}Available on crate feature
posix-tz only.Expand description
The main type of error that is returned when a TZ POSIX string fails to parse.
Variants
Nom(ErrorKind)
A nom parsing error.
UnknownName(&'a str)
In case a short format was given, the POSIX standard doesn’t define what to do, in this implementation we just try to match the first tzdb timezone containing the short name; if none could be found this error variant is returned.
Range(RangeError)
We’ve exceeded the range of a field when checking for conformance against the POSIX standard.
ComponentRange(ComponentRange)
We’ve exceeded the range of a date component when converting types to time-rs.